pygeodesy.karney.Rhumb8Tuple

Package pygeodesy :: Module karney :: Class Rhumb8Tuple |
[frames] | no frames]

# Class Rhumb8Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                  _GTuple --+
                            |
                           Rhumb8Tuple

Known Subclasses:
  - rhumb.solve.RhumbSolve7Tuple

8-Tuple `(lat1, lon1, lat2, lon2, azi12, s12, S12, a12)` with lat- `lat1`, `lat2` and longitudes `lon1`, `lon2` of both points, the azimuth of the rhumb line `azi12`, the distance `s12`, the area `S12` under the rhumb line and the angular distance `a12` between both points.

Instance Methods
toDirect9Tuple(self, dflt=nan, **a12_azi1_azi2_m12_M12_M21) Convert this Rhumb8Tuple result to a 9-tuple, like Karney's method `geographiclib.geodesic.Geodesic._GenDirect`. |
toInverse10Tuple(self, dflt=nan, **a12_m12_M12_M21_salp1_calp1_salp2_calp2) Convert this Rhumb8Tuple to a 10-tuple, like Karney's method `geographiclib.geodesic.Geodesic._GenInverse`. |
Inherited from `_GTuple`: `toGDict` Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toDirect9Tuple (self, dflt=nan, **a12_azi1_azi2_m12_M12_M21) |
Convert this Rhumb8Tuple result to a 9-tuple, like Karney's method `geographiclib.geodesic.Geodesic._GenDirect`. Arguments: `dflt` - Default value for missing items (`any`). `a12_azi1_azi2_m12_M12_M21` - Optional keyword arguments to specify or override Inverse10Tuple items. Returns: Direct9Tuple`(a12, lat2, lon2, azi2, s12, m12, M12, M21, S12)`

### toInverse10Tuple (self, dflt=nan, **a12_m12_M12_M21_salp1_calp1_salp2_calp2) |
Convert this Rhumb8Tuple to a 10-tuple, like Karney's method `geographiclib.geodesic.Geodesic._GenInverse`. Arguments: `dflt` - Default value for missing items (`any`). `a12_m12_M12_M21_salp1_calp1_salp2_calp2` - Optional keyword arguments to specify or override Inverse10Tuple items. Returns: Inverse10Tuple`(a12, s12, salp1, calp1, salp2, calp2, m12, M12, M21, S12)`.